==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/NextYearExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { NextYearExpressionDescription } from "./NextYearExpressionDescription";
/**
 * @hidden
 */
export let NextYearExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class NextYearExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (NextYearExpressionDescriptionMetadata.a == null) {
                NextYearExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NextYearExpressionDescriptionMetadata.c(NextYearExpressionDescriptionMetadata.a);
            }
            if (a.j(NextYearExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(NextYearExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            NextYearExpressionDescriptionMetadata.b(a);
            a.aa("NextYearExpression", () => new NextYearExpressionDescription());
            a.z("NextYearExpression", NextYearExpressionDescriptionMetadata.a);
        }
    }
    NextYearExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(NextYearExpressionDescriptionMetadata, 'NextYearExpressionDescriptionMetadata');
    NextYearExpressionDescriptionMetadata.a = null;
    return NextYearExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/NextYearExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { NextYearExpressionDescription } from "./NextYearExpressionDescription";
/**
 * @hidden
 */
export let NextYearExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class NextYearExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (NextYearExpressionDescriptionMetadata.a == null) {
                NextYearExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NextYearExpressionDescriptionMetadata.c(NextYearExpressionDescriptionMetadata.a);
            }
            if (a.k(NextYearExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(NextYearExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            NextYearExpressionDescriptionMetadata.b(a);
            a.ac("NextYearExpression", () => new NextYearExpressionDescription());
            a.ab("NextYearExpression", NextYearExpressionDescriptionMetadata.a);
        }
    }
    NextYearExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(NextYearExpressionDescriptionMetadata, 'NextYearExpressionDescriptionMetadata');
    NextYearExpressionDescriptionMetadata.a = null;
    return NextYearExpressionDescriptionMetadata;
})();
